@@ -151,7 +151,7 @@ void BarCodeDialog::save()
             bc.setTokenProvider( m_token );
             bc.update( TQT_TQPAINTDEVICE(TDEApplication::desktop()) );
 
-            if(!bc.pixmap().save( path, extension, 0 ))
+            if(!bc.pixmap().save( path, extension.utf8(), 0 ))
                 KMessageBox::error( this, i18n("An error occurred during saving the image") );
         }
     }        
