@@ -308,7 +308,7 @@ void BatchPrinter::startImages()
                 c++;
             }
 
-            pixmap.save( filename, m_image_format );
+            pixmap.save( filename, m_image_format.utf8() );
 
             if( !checkProgressDialog( progress ) )
 	    {
