@@ -248,7 +248,7 @@ TQRect PixmapBarcode::bbox( const char* data, long size )
         if( text.startsWith( bbox ) )
         {
             text = text.right( text.length() - len );
-            sscanf( (const char*)text, "%d %d %d %d", &x, &y, &w, &h );
+            sscanf( text.latin1(), "%d %d %d %d", &x, &y, &w, &h );
             s = TQRect( x, y, w, h );
             break;
         }
