@@ -16,11 +16,11 @@
 #include <tqwidget.h>
 #include <knuminput.h>
 
-class KActionCollection;
-class KToggleAction;
-class KFontAction;
-class KFontSizeAction;
-class KToolBar;
+class TDEActionCollection;
+class TDEToggleAction;
+class TDEFontAction;
+class TDEFontSizeAction;
+class TDEToolBar;
 class KSpell;
 class KSpellConfig;
 class KComboBox;
@@ -30,7 +30,7 @@ class KLineEdit;
 
 class TextLineEditor : public TQWidget {
     Q_OBJECT
-  TQ_OBJECT
+  
     public:
         TextLineEditor( TokenProvider* token, TQWidget *parent=0, const char *name=0);
         ~TextLineEditor();
@@ -57,12 +57,12 @@ class TextLineEditor : public TQWidget {
 
         KLineEdit* editor;
 
-        KActionCollection* ac;
+        TDEActionCollection* ac;
         
 	KComboBox *action_font_type ;
-        KToolBar* toolBar;
-        KToolBar* tool2Bar;
-	KToolBar* tool3Bar;
+        TDEToolBar* toolBar;
+        TDEToolBar* tool2Bar;
+	TDEToolBar* tool3Bar;
 	
 	
   
