@@ -905,7 +905,7 @@ const TQString TokenProvider::createSerial()
         tmpstr.setNum(splitit.cap(2).length());
         TQString formatstring = "%0" + tmpstr + "lu";
 
-        s = prenum + tmpstr.sprintf(formatstring, tmp) + postnum;
+        s = prenum + tmpstr.sprintf(formatstring.latin1(), tmp) + postnum;
         m_update = true;
     }
 
